pub struct BrwLockPiWriteGuard<'a, Class: LockClass> { /* private fields */ }Expand description
A validation guard representing writer lock ownership and active list participation.
Implementations
Sourceimpl<'a, Class: LockClass> BrwLockPiWriteGuard<'a, Class>
impl<'a, Class: LockClass> BrwLockPiWriteGuard<'a, Class>
Sourceimpl<'a, Class: LockClass> BrwLockPiWriteGuard<'a, Class>
impl<'a, Class: LockClass> BrwLockPiWriteGuard<'a, Class>
Sourcepub fn new(lock: &'a BrwLockPi<Class>) -> impl PinInit<Self, Infallible>
pub fn new(lock: &'a BrwLockPi<Class>) -> impl PinInit<Self, Infallible>
Creates a new stack-pinned validation guard initialization block.
Sourcepub fn token(&self) -> &LockToken<'a, Class>
pub fn token(&self) -> &LockToken<'a, Class>
Returns a shared reference to the lock proof LockToken.
Sourcepub fn token_mut(self: Pin<&mut Self>) -> &mut LockToken<'a, Class>
pub fn token_mut(self: Pin<&mut Self>) -> &mut LockToken<'a, Class>
Returns a mutable reference to the lock proof LockToken inside this pinned projection.
Sourcepub fn call_unlocked<R, F: FnOnce() -> R>(self: Pin<&mut Self>, f: F) -> R
pub fn call_unlocked<R, F: FnOnce() -> R>(self: Pin<&mut Self>, f: F) -> R
Temporarily releases the write lock before executing the given callable f and then
re-acquires the write lock.