KMutexAliasedGuard

Struct KMutexAliasedGuard 

pub struct KMutexAliasedGuard<'a, Class1: LockClass, Class2: LockClass, M1: RawLock = RawMutex, M2: RawLock = M1, P: LockPolicy<M1> = <M1 as RawLock>::DefaultPolicy> { /* private fields */ }
A validation guard representing ownership of two aliased locks simultaneously.

Only the first lock is physically acquired, but proof tokens for both lock classes (Class1 and Class2) are provided.

Implementations

Source

impl<'a, Class1: LockClass, Class2: LockClass, M1: RawLock, M2: RawLock, P: LockPolicy<M1>> KMutexAliasedGuard<'a, Class1, Class2, M1, M2, P>

pub fn project<'__pin>( self: Pin<&'__pin mut Self>, ) -> KMutexAliasedGuardProjection<'__pin, 'a, Class1, Class2, M1, M2, P>

Pin-projects all fields of Self.

These fields are structurally pinned:

  • inner

These fields are not structurally pinned:

  • token2
  • _phantom
Source

impl<'a, Class1: LockClass, Class2: LockClass, M1: RawLock, M2: RawLock, P: LockPolicy<M1>> KMutexAliasedGuard<'a, Class1, Class2, M1, M2, P>

pub fn new( lock1: &'a KMutex<Class1, M1>, lock2: &'a KMutex<Class2, M2>, ) -> impl PinInit<Self, Infallible>
where P: LockPolicy<M1, AcquireArgs = ()>,

Creates a new stack-pinned aliased validation guard initialization block.

pub fn new_with_args( lock1: &'a KMutex<Class1, M1>, _lock2: &'a KMutex<Class2, M2>, args: P::AcquireArgs, ) -> impl PinInit<Self, Infallible>

Creates a new stack-pinned aliased validation guard initialization block with policy acquire arguments.

pub fn tokens(&self) -> (&LockToken<'a, Class1>, &LockToken<'a, Class2>)

Returns shared references to both lock proof tokens (Class1, Class2).

pub fn tokens_mut( self: Pin<&mut Self>, ) -> (&mut LockToken<'a, Class1>, &mut LockToken<'a, Class2>)

Returns simultaneous mutable references to both proof tokens (Class1, Class2).

pub fn token(&self) -> &LockToken<'a, Class1>

Returns a shared reference to the primary lock proof token (Class1).

pub fn token_mut(self: Pin<&mut Self>) -> &mut LockToken<'a, Class1>

Returns a mutable reference to the primary lock proof token (Class1).

pub fn inner_guard( self: Pin<&mut Self>, ) -> Pin<&mut KMutexGuard<'a, Class1, M1, P>>

Returns a pinned mutable reference to the primary inner KMutexGuard.

pub fn call_unlocked<R, F: FnOnce() -> R>(self: Pin<&mut Self>, f: F) -> R

Temporarily releases the lock before executing the given callable f and then re-acquires the lock.

pub fn call_untracked<R, F: FnOnce(&mut LockToken<'a, Class1>, &mut LockToken<'a, Class2>) -> R>( self: Pin<&mut Self>, f: F, ) -> R

Calls a closure while temporarily disabling lockdep tracking for the lock held by this guard.