KMutexGuard

Struct KMutexGuard 

pub struct KMutexGuard<'a, Class: LockClass, M: RawLock = RawMutex, P: LockPolicy<M> = <M as RawLock>::DefaultPolicy> { /* private fields */ }
A validation guard representing exclusive lock ownership and active list participation.

The guard is pinned in memory to ensure that its lock_entry pointer remains safe and valid inside the C++ loop detector active thread list.

Implementations

Source

impl<'a, Class: LockClass, M: RawLock, P: LockPolicy<M>> KMutexGuard<'a, Class, M, P>

pub fn project<'__pin>( self: Pin<&'__pin mut Self>, ) -> KMutexGuardProjection<'__pin, 'a, Class, M, P>

Pin-projects all fields of Self.

These fields are structurally pinned:

  • lock_entry

These fields are not structurally pinned:

  • mutex
  • state
  • token
Source

impl<'a, Class: LockClass, M: RawLock, P: LockPolicy<M>> KMutexGuard<'a, Class, M, P>

pub fn new(mutex: &'a KMutex<Class, M>) -> impl PinInit<Self, Infallible>
where P: LockPolicy<M, AcquireArgs = ()>,

Creates a new stack-pinned validation guard initialization block.

pub fn new_with_args( mutex: &'a KMutex<Class, M>, args: P::AcquireArgs, ) -> impl PinInit<Self, Infallible>

Creates a new stack-pinned validation guard initialization block with policy acquire arguments.

pub fn token(&self) -> &LockToken<'a, Class>

Returns a shared reference to the lock proof LockToken.

pub fn token_mut(self: Pin<&mut Self>) -> &mut LockToken<'a, Class>

Returns a mutable reference to the lock proof LockToken inside this pinned projection.

pub fn call_unlocked<R, F: FnOnce() -> R>(self: Pin<&mut Self>, f: F) -> R

Temporarily releases the lock before executing the given callable f and then re-acquires the lock.

pub fn call_untracked<R, F: FnOnce(&mut LockToken<'a, Class>) -> R>( self: Pin<&mut Self>, f: F, ) -> R

Calls a closure while temporarily disabling lockdep tracking for the lock held by this guard.