pub struct LockToken<'a, Class> { /* private fields */ }Expand description
A token proving that a lock of lock class Class is currently held by the current thread.
This token acts as a static proof to permit type-safe borrow access to cell values guarded by
this lock class (via KCell).
Implementations
Sourceimpl<'a, Class> LockToken<'a, Class>
impl<'a, Class> LockToken<'a, Class>
Sourcepub unsafe fn new() -> Self
pub unsafe fn new() -> Self
Creates a new proof token for the lock class Class.
Safety
The caller must guarantee that the mutual exclusion lock associated with this lock class is
currently held by the current thread and that the lifetime 'a is bounded to the duration
of the lock being held. Creating a token when the lock is not held, or letting the token
outlive the lock hold duration, can lead to concurrent mutation or data races, which is
undefined behavior.