pub struct NoIrqSavePolicy;Trait Implementations
Sourceimpl LockPolicy<RawMonitoredSpinlock> for NoIrqSavePolicy
impl LockPolicy<RawMonitoredSpinlock> for NoIrqSavePolicy
Sourcetype AcquireArgs = SourceTag
type AcquireArgs = SourceTag
Arguments passed when acquiring the lock under this policy.
Sourcetype GuardState = SourceTag
type GuardState = SourceTag
State returned from lock acquisition and subsequently passed to lock release.
Sourceunsafe fn acquire(
lock: &RawMonitoredSpinlock,
entry: *mut LockEntryStorage,
tag: Self::AcquireArgs,
) -> Self::GuardState
unsafe fn acquire( lock: &RawMonitoredSpinlock, entry: *mut LockEntryStorage, tag: Self::AcquireArgs, ) -> Self::GuardState
Acquires the raw synchronization lock under a type-level lock class. Read more
Sourceunsafe fn reacquire(
lock: &RawMonitoredSpinlock,
entry: *mut LockEntryStorage,
state: &mut Self::GuardState,
)
unsafe fn reacquire( lock: &RawMonitoredSpinlock, entry: *mut LockEntryStorage, state: &mut Self::GuardState, )
Re-acquires the raw synchronization lock using existing guard state (e.g. after
call_unlocked). Read moreSourceunsafe fn release(
lock: &RawMonitoredSpinlock,
entry: *mut LockEntryStorage,
_state: Self::GuardState,
)
unsafe fn release( lock: &RawMonitoredSpinlock, entry: *mut LockEntryStorage, _state: Self::GuardState, )
Releases the raw synchronization lock, restoring the state. Read more
Sourceimpl LockPolicy<RawSpinlock> for NoIrqSavePolicy
impl LockPolicy<RawSpinlock> for NoIrqSavePolicy
Sourcetype AcquireArgs = ()
type AcquireArgs = ()
Arguments passed when acquiring the lock under this policy.
Sourcetype GuardState = ()
type GuardState = ()
State returned from lock acquisition and subsequently passed to lock release.
Sourceunsafe fn acquire(
lock: &RawSpinlock,
entry: *mut LockEntryStorage,
_args: (),
) -> Self::GuardState
unsafe fn acquire( lock: &RawSpinlock, entry: *mut LockEntryStorage, _args: (), ) -> Self::GuardState
Acquires the raw synchronization lock under a type-level lock class. Read more
Sourceunsafe fn reacquire(
lock: &RawSpinlock,
entry: *mut LockEntryStorage,
state: &mut Self::GuardState,
)
unsafe fn reacquire( lock: &RawSpinlock, entry: *mut LockEntryStorage, state: &mut Self::GuardState, )
Re-acquires the raw synchronization lock using existing guard state (e.g. after
call_unlocked). Read moreSourceunsafe fn release(
lock: &RawSpinlock,
entry: *mut LockEntryStorage,
_state: Self::GuardState,
)
unsafe fn release( lock: &RawSpinlock, entry: *mut LockEntryStorage, _state: Self::GuardState, )
Releases the raw synchronization lock, restoring the state. Read more