pub struct KMutexGuard<'a, Class: LockClass, M: RawLock = RawMutex, P: LockPolicy<M> = <M as RawLock>::DefaultPolicy> { /* private fields */ }Expand description
A validation guard representing exclusive lock ownership and active list participation.
The guard is pinned in memory to ensure that its lock_entry pointer remains safe and valid
inside the C++ loop detector active thread list.
Implementations
Sourceimpl<'a, Class: LockClass, M: RawLock, P: LockPolicy<M>> KMutexGuard<'a, Class, M, P>
impl<'a, Class: LockClass, M: RawLock, P: LockPolicy<M>> KMutexGuard<'a, Class, M, P>
Sourceimpl<'a, Class: LockClass, M: RawLock, P: LockPolicy<M>> KMutexGuard<'a, Class, M, P>
impl<'a, Class: LockClass, M: RawLock, P: LockPolicy<M>> KMutexGuard<'a, Class, M, P>
Sourcepub fn new(mutex: &'a KMutex<Class, M>) -> impl PinInit<Self, Infallible>where
P: LockPolicy<M, AcquireArgs = ()>,
pub fn new(mutex: &'a KMutex<Class, M>) -> impl PinInit<Self, Infallible>where
P: LockPolicy<M, AcquireArgs = ()>,
Creates a new stack-pinned validation guard initialization block.
Sourcepub fn new_with_args(
mutex: &'a KMutex<Class, M>,
args: P::AcquireArgs,
) -> impl PinInit<Self, Infallible>
pub fn new_with_args( mutex: &'a KMutex<Class, M>, args: P::AcquireArgs, ) -> impl PinInit<Self, Infallible>
Creates a new stack-pinned validation guard initialization block with policy acquire arguments.
Sourcepub fn token(&self) -> &LockToken<'a, Class>
pub fn token(&self) -> &LockToken<'a, Class>
Returns a shared reference to the lock proof LockToken.
Sourcepub fn token_mut(self: Pin<&mut Self>) -> &mut LockToken<'a, Class>
pub fn token_mut(self: Pin<&mut Self>) -> &mut LockToken<'a, Class>
Returns a mutable reference to the lock proof LockToken inside this pinned projection.
Sourcepub fn call_unlocked<R, F: FnOnce() -> R>(self: Pin<&mut Self>, f: F) -> R
pub fn call_unlocked<R, F: FnOnce() -> R>(self: Pin<&mut Self>, f: F) -> R
Temporarily releases the lock before executing the given callable f and then
re-acquires the lock.
Sourcepub fn call_untracked<R, F: FnOnce(&mut LockToken<'a, Class>) -> R>(
self: Pin<&mut Self>,
f: F,
) -> R
pub fn call_untracked<R, F: FnOnce(&mut LockToken<'a, Class>) -> R>( self: Pin<&mut Self>, f: F, ) -> R
Calls a closure while temporarily disabling lockdep tracking for the lock held by this guard.