pub struct KMutexGuard<'a, Class: LockClass, M: RawLock = RawMutex> { /* private fields */ }Expand description
A validation guard representing exclusive lock ownership and active list participation.
The guard is pinned in memory to ensure that its lock_entry pointer remains safe and valid
inside the C++ loop detector active thread list.
Implementations
Sourceimpl<'a, Class: LockClass, M: RawLock> KMutexGuard<'a, Class, M>
impl<'a, Class: LockClass, M: RawLock> KMutexGuard<'a, Class, M>
Sourceimpl<'a, Class: LockClass, M: RawLock> KMutexGuard<'a, Class, M>
impl<'a, Class: LockClass, M: RawLock> KMutexGuard<'a, Class, M>