KMutexGuard

Struct KMutexGuard 

pub struct KMutexGuard<'a, Class: LockClass, M: RawLock = RawMutex> { /* private fields */ }
A validation guard representing exclusive lock ownership and active list participation.

The guard is pinned in memory to ensure that its lock_entry pointer remains safe and valid inside the C++ loop detector active thread list.

Implementations

Source

impl<'a, Class: LockClass, M: RawLock> KMutexGuard<'a, Class, M>

pub fn project<'__pin>( self: Pin<&'__pin mut Self>, ) -> KMutexGuardProjection<'__pin, 'a, Class, M>

Pin-projects all fields of Self.

These fields are structurally pinned:

  • lock_entry

These fields are not structurally pinned:

  • mutex
  • state
  • token
Source

impl<'a, Class: LockClass, M: RawLock> KMutexGuard<'a, Class, M>

pub fn new(mutex: &'a KMutex<Class, M>) -> impl PinInit<Self, Infallible>

Creates a new stack-pinned validation guard initialization block.

pub fn token(&self) -> &LockToken<'a, Class>

Returns a shared reference to the lock proof LockToken.

pub fn token_mut(self: Pin<&mut Self>) -> &mut LockToken<'a, Class>

Returns a mutable reference to the lock proof LockToken inside this pinned projection.